Module crossref

Module crossref 

Functions

fetch
Fetch a work from the Crossref REST API by DOI and convert it to Data.
fetch_all
Fetch a list of works from the Crossref API and convert them to Data.
fetch_all_by_orcid
Fetch all works by ORCID from Crossref using cursor-based pagination.
fetch_by_orcid
Fetch works by ORCID from the Crossref REST API, sorted by date descending.
fetch_by_ror
fetch_page_with_cursor
Fetch one page of Crossref works using cursor-based pagination. Returns (items, next_cursor). When next_cursor is None or the items list is shorter than number, iteration should stop.
read_json
Parse a Crossref API JSON response (the full {"status":"ok","message":{...}} envelope).
write
Serialize a Data record as a Crossref REST API JSON response.
write_all
Serialize a list of Data records as a Crossref REST API work-list response.