Module schema_utils

Module schema_utils 

JSON Schema and XSD validation utilities.

Constants

DEFAULT_SCHEMA
SCHEMA_JSON
SCHEMA_VERSION

Functions

json_schema_errors
Validate a JSON document against one of the bundled schema names.
known_schemata
Return the list of schema names accepted by json_schema_errors.
xml_schema_errors
Validate an XML document against a bundled XSD schema.