Module schema_utils

Module schema_utils 

JSON Schema validation utilities.

Constants

SCHEMA_VERSION

Functions

json_schema_errors
Validate a JSON document against one of the bundled schema names.
known_schemata
Return the list of schema names accepted by json_schema_errors.